Welcome to NB-QOL's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   quickstart
   api/modules


NB-QOL: Jupyter Notebook Quality of Life
========================================

NB-QOL is a cross-platform, modular, quality-of-life tool kit for working with Jupyter notebooks wherever you work with them.

Features
--------

* CUDA device management utilities
* Output capture and display tools
* Path operations and Git repository detection
* IPython environment configuration
* CSS styling for notebooks in different environments

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`